@@ -136,7 +136,7 @@ impl_candlestick!(BitmexWSClient);
 
 panic_l3_orderbook!(BitmexWSClient);
 
-define_client!(
+impl_new_constructor!(
     BitmexWSClient,
     EXCHANGE_NAME,
     WEBSOCKET_URL,
@@ -145,6 +145,7 @@ define_client!(
     Some(CLIENT_PING_INTERVAL_AND_MSG),
     None
 );
+impl_ws_client_trait!(BitmexWSClient);
 
 #[cfg(test)]
 mod tests {
